/*
 *      Copyright (c) 2015 Samsung Electronics Co., Ltd
 *
 *      Licensed under the Flora License, Version 1.1 (the "License");
 *      you may not use this file except in compliance with the License.
 *      You may obtain a copy of the License at
 *
 *              http://floralicense.org/license/
 *
 *      Unless required by applicable law or agreed to in writing, software
 *      distributed under the License is distributed on an "AS IS" BASIS,
 *      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *      See the License for the specific language governing permissions and
 *      limitations under the License.
 */

/*global define*/

/**
 * Constants module.
 *
 * @module helpers/constants
 * @namespace helpers/constants
 */

define({
    name: 'helpers/constants',
    requires: [],
    def: function helpersConstants() {
        'use strict';

        /**
         * Gallery minimal width.
         *
         * @memberof helpers/constants
         * @public
         * @const {number}
         */
        var GALLERY_MIN_WIDTH = 360,

            /**
             * Grid view (3x3) element width.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            GRID_ELEMENT_WIDTH = 114,

            /**
             * Grid view (3x3) first row top margin.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            GRID_FIRST_TOP = 23,

            /**
             * Grid view (3x3) first row left margin.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            GRID_FIRST_LEFT = 66,

            /**
             * Grid view (3x3) second row top margin.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            GRID_SECOND_TOP = 124,

            /**
             * Grid view (3x3) second row left margin.
             *
             * @memberof helpers/constants
             * @private
             * @const {number}
             */
            GRID_SECOND_LEFT = 9,

            /**
             * Grid view (3x3) third row top margin.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            GRID_THIRD_TOP = 225,

            /**
             * Grid view (3x3) third row left margin.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            GRID_THIRD_LEFT = 66,

            /**
             * Line view element width.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            LINE_ELEMENT_WIDTH = 241,

            /**
             * Line view element top margin.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            LINE_TOP = 47,

            /**
             * Line view element left margin.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            LINE_LEFT = 59.5,

            /**
             * Full view element width.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            FULL_ELEMENT_WIDTH = 360,

            /**
             * Full view element top margin.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            FULL_TOP = 0,

            /**
             * Full view element left margin.
             *
             * @memberof helpers/constants
             * @public
             * @const {number}
             */
            FULL_LEFT = 0,

            /**
             * Pixel value string.
             *
             * @memberof helpers/constants
             * @public
             * @const {string}
             */
            PIXEL = 'px',

            /**
             * Display mode.
             *
             * @memberof helpers/constants
             * @public
             * @const {Object}
             */
            MODE = Object.freeze({
                GRID: 0,
                LINE: 1,
                FULL: 2,
                SELECT: 3,
                ZOOM: 4
            });

        return {
            GALLERY_MIN_WIDTH: GALLERY_MIN_WIDTH,
            GRID_ELEMENT_WIDTH: GRID_ELEMENT_WIDTH,
            GRID_FIRST_TOP: GRID_FIRST_TOP,
            GRID_FIRST_LEFT: GRID_FIRST_LEFT,
            GRID_SECOND_TOP: GRID_SECOND_TOP,
            GRID_SECOND_LEFT: GRID_SECOND_LEFT,
            GRID_THIRD_TOP: GRID_THIRD_TOP,
            GRID_THIRD_LEFT: GRID_THIRD_LEFT,
            LINE_ELEMENT_WIDTH: LINE_ELEMENT_WIDTH,
            LINE_TOP: LINE_TOP,
            LINE_LEFT: LINE_LEFT,
            FULL_ELEMENT_WIDTH: FULL_ELEMENT_WIDTH,
            FULL_TOP: FULL_TOP,
            FULL_LEFT: FULL_LEFT,

            PIXEL: PIXEL,
            MODE: MODE
        };
    }
});
