/*
 *      Copyright (c) 2015 Samsung Electronics Co., Ltd
 *
 *      Licensed under the Flora License, Version 1.1 (the "License");
 *      you may not use this file except in compliance with the License.
 *      You may obtain a copy of the License at
 *
 *              http://floralicense.org/license/
 *
 *      Unless required by applicable law or agreed to in writing, software
 *      distributed under the License is distributed on an "AS IS" BASIS,
 *      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *      See the License for the specific language governing permissions and
 *      limitations under the License.
 */

/*global define, document*/

/**
 * Empty view module.
 *
 * @module views/empty
 * @namespace views/empty
 */

define({
    name: 'views/empty',
    requires: [],
    def: function viewsSend() {
        'use strict';

        /**
         * Class dictionary.
         *
         * @memberof views/empty
         * @private
         * @const {Object}
         */
        var CLASSES = Object.freeze({
                PRESSED: 'pressed'
            }),

            /**
             * Id dictionary.
             *
             * @memberof views/empty
             * @private
             * @const {Object}
             */
            ID = Object.freeze({
                ICON: 'empty-icon'
            }),

            /**
             * Icon element.
             *
             * @memberof views/empty
             * @private
             * @type {HTMLElement}
             */
            icon = null;

        /**
         * Touch start event handler.
         *
         * @memberof views/empty
         * @private
         */
        function onTouchStart() {
            icon.classList.add(CLASSES.PRESSED);
        }

        /**
         * Touch end event handler.
         *
         * @memberof views/empty
         * @private
         */
        function onTouchEnd() {
            icon.classList.remove(CLASSES.PRESSED);
        }

        /**
         * Registers event handlers.
         *
         * @memberof views/empty
         * @private
         */
        function bindEvents() {
            icon.addEventListener('touchstart', onTouchStart);
            icon.addEventListener('touchend', onTouchEnd);
        }

        /**
         * Initializes the module.
         *
         * @memberof views/empty
         * @public
         */
        function init() {
            icon = document.getElementById(ID.ICON);

            bindEvents();
        }

        return {
            init: init
        };
    }
});
